# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v0_constraints.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import v0_messages_pb2 as v0__messages__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from . import v0_summaries_pb2 as v0__summaries__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14v0_constraints.proto\x1a\x11v0_messages.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x12v0_summaries.proto\"\xcf\x03\n\x14SummaryConstraintMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x66irst_field\x18\x02 \x01(\t\x12\x16\n\x0csecond_field\x18\x03 \x01(\tH\x00\x12\x0f\n\x05value\x18\x04 \x01(\x01H\x00\x12/\n\x07\x62\x65tween\x18\x07 \x01(\x0b\x32\x1c.SummaryBetweenConstraintMsgH\x00\x12\x33\n\rreference_set\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x00\x12\x13\n\tvalue_str\x18\x0c \x01(\tH\x00\x12\x0f\n\x02op\x18\x05 \x01(\x0e\x32\x03.Op\x12\x0f\n\x07verbose\x18\x06 \x01(\x08\x12\x16\n\x0equantile_value\x18\t \x01(\x01\x12J\n\x17\x63ontinuous_distribution\x18\n \x01(\x0b\x32\'.ReferenceDistributionContinuousMessageH\x01\x12\x46\n\x15\x64iscrete_distribution\x18\x0b \x01(\x0b\x32%.ReferenceDistributionDiscreteMessageH\x01\x42\x08\n\x06secondB\x18\n\x16reference_distribution\"Q\n&ReferenceDistributionContinuousMessage\x12\'\n\x06sketch\x18\x01 \x01(\x0b\x32\x17.KllFloatsSketchMessage\"\x95\x01\n$ReferenceDistributionDiscreteMessage\x12-\n\x0e\x66requent_items\x18\x01 \x01(\x0b\x32\x15.FrequentItemsSummary\x12)\n\x0cunique_count\x18\x02 \x01(\x0b\x32\x13.UniqueCountSummary\x12\x13\n\x0btotal_count\x18\x03 \x01(\x02\"\x8c\x01\n\x1bSummaryBetweenConstraintMsg\x12\x16\n\x0csecond_field\x18\x01 \x01(\tH\x00\x12\x15\n\x0blower_value\x18\x02 \x01(\x01H\x00\x12\x15\n\x0bthird_field\x18\x03 \x01(\tH\x01\x12\x15\n\x0bupper_value\x18\x04 \x01(\x01H\x01\x42\x07\n\x05lowerB\x07\n\x05upper\"=\n\x10\x41pplyFunctionMsg\x12\x10\n\x08\x66unction\x18\x01 \x01(\t\x12\x17\n\x0freference_value\x18\x02 \x01(\t\"\xf7\x01\n\x12ValueConstraintMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x05value\x18\x02 \x01(\x01H\x00\x12\x17\n\rregex_pattern\x18\x05 \x01(\tH\x00\x12/\n\tvalue_set\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x00\x12%\n\x08\x66unction\x18\x07 \x01(\x0b\x32\x11.ApplyFunctionMsgH\x00\x12\x0f\n\x02op\x18\x03 \x01(\x0e\x32\x03.Op\x12\x0f\n\x07verbose\x18\x04 \x01(\x08\x12\r\n\x05total\x18\x08 \x01(\r\x12\x10\n\x08\x66\x61ilures\x18\t \x01(\rB\x0e\n\x0csecond_field\"\x86\x03\n\x1dMultiColumnValueConstraintMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\x11\x64\x65pendent_columns\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x00\x12\x1a\n\x10\x64\x65pendent_column\x18\x03 \x01(\tH\x00\x12\x0f\n\x05value\x18\x06 \x01(\x01H\x01\x12/\n\tvalue_set\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x01\x12\x37\n\x11reference_columns\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x01\x12\x0f\n\x02op\x18\x04 \x01(\x0e\x32\x03.Op\x12\x0f\n\x07verbose\x18\x05 \x01(\x08\x12*\n\x1dinternal_dependent_columns_op\x18\t \x01(\x0e\x32\x03.Op\x12\r\n\x05total\x18\n \x01(\r\x12\x10\n\x08\x66\x61ilures\x18\x0b \x01(\rB\x0b\n\tdependentB\x0b\n\treference\"\x81\x01\n\x13ValueConstraintMsgs\x12(\n\x0b\x63onstraints\x18\x01 \x03(\x0b\x32\x13.ValueConstraintMsg\x12@\n\x18multi_column_constraints\x18\x02 \x03(\x0b\x32\x1e.MultiColumnValueConstraintMsg\"C\n\x15SummaryConstraintMsgs\x12*\n\x0b\x63onstraints\x18\x01 \x03(\x0b\x32\x15.SummaryConstraintMsg\"\xed\x03\n\x14\x44\x61tasetConstraintMsg\x12(\n\nproperties\x18\x01 \x01(\x0b\x32\x14.DatasetPropertiesV0\x12\x46\n\x11value_constraints\x18\x02 \x03(\x0b\x32+.DatasetConstraintMsg.ValueConstraintsEntry\x12J\n\x13summary_constraints\x18\x03 \x03(\x0b\x32-.DatasetConstraintMsg.SummaryConstraintsEntry\x12\x37\n\x17table_shape_constraints\x18\x04 \x01(\x0b\x32\x16.SummaryConstraintMsgs\x12<\n\x1emulti_column_value_constraints\x18\x05 \x01(\x0b\x32\x14.ValueConstraintMsgs\x1aM\n\x15ValueConstraintsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.ValueConstraintMsgs:\x02\x38\x01\x1aQ\n\x17SummaryConstraintsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.SummaryConstraintMsgs:\x02\x38\x01*\xc5\x01\n\x02Op\x12\n\n\x06unused\x10\x00\x12\x06\n\x02LT\x10\x01\x12\x06\n\x02LE\x10\x02\x12\x06\n\x02\x45Q\x10\x03\x12\x06\n\x02NE\x10\x04\x12\x06\n\x02GE\x10\x05\x12\x06\n\x02GT\x10\x06\x12\t\n\x05MATCH\x10\x07\x12\x0b\n\x07NOMATCH\x10\x08\x12\x08\n\x04\x42TWN\x10\t\x12\n\n\x06IN_SET\x10\n\x12\x0f\n\x0b\x43ONTAIN_SET\x10\x0b\x12\n\n\x06\x45Q_SET\x10\x0c\x12\x0e\n\nAPPLY_FUNC\x10\r\x12\x06\n\x02IN\x10\x0e\x12\x0b\n\x07\x43ONTAIN\x10\x0f\x12\n\n\x06NOT_IN\x10\x10\x12\x07\n\x03SUM\x10\x11\x42/\n\x1e\x63om.whylogs.v0.core.constraintB\x0b\x43onstraintsP\x01\x62\x06proto3')

_OP = DESCRIPTOR.enum_types_by_name['Op']
Op = enum_type_wrapper.EnumTypeWrapper(_OP)
unused = 0
LT = 1
LE = 2
EQ = 3
NE = 4
GE = 5
GT = 6
MATCH = 7
NOMATCH = 8
BTWN = 9
IN_SET = 10
CONTAIN_SET = 11
EQ_SET = 12
APPLY_FUNC = 13
IN = 14
CONTAIN = 15
NOT_IN = 16
SUM = 17


_SUMMARYCONSTRAINTMSG = DESCRIPTOR.message_types_by_name['SummaryConstraintMsg']
_REFERENCEDISTRIBUTIONCONTINUOUSMESSAGE = DESCRIPTOR.message_types_by_name['ReferenceDistributionContinuousMessage']
_REFERENCEDISTRIBUTIONDISCRETEMESSAGE = DESCRIPTOR.message_types_by_name['ReferenceDistributionDiscreteMessage']
_SUMMARYBETWEENCONSTRAINTMSG = DESCRIPTOR.message_types_by_name['SummaryBetweenConstraintMsg']
_APPLYFUNCTIONMSG = DESCRIPTOR.message_types_by_name['ApplyFunctionMsg']
_VALUECONSTRAINTMSG = DESCRIPTOR.message_types_by_name['ValueConstraintMsg']
_MULTICOLUMNVALUECONSTRAINTMSG = DESCRIPTOR.message_types_by_name['MultiColumnValueConstraintMsg']
_VALUECONSTRAINTMSGS = DESCRIPTOR.message_types_by_name['ValueConstraintMsgs']
_SUMMARYCONSTRAINTMSGS = DESCRIPTOR.message_types_by_name['SummaryConstraintMsgs']
_DATASETCONSTRAINTMSG = DESCRIPTOR.message_types_by_name['DatasetConstraintMsg']
_DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY = _DATASETCONSTRAINTMSG.nested_types_by_name['ValueConstraintsEntry']
_DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY = _DATASETCONSTRAINTMSG.nested_types_by_name['SummaryConstraintsEntry']
SummaryConstraintMsg = _reflection.GeneratedProtocolMessageType('SummaryConstraintMsg', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYCONSTRAINTMSG,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:SummaryConstraintMsg)
  })
_sym_db.RegisterMessage(SummaryConstraintMsg)

ReferenceDistributionContinuousMessage = _reflection.GeneratedProtocolMessageType('ReferenceDistributionContinuousMessage', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCEDISTRIBUTIONCONTINUOUSMESSAGE,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:ReferenceDistributionContinuousMessage)
  })
_sym_db.RegisterMessage(ReferenceDistributionContinuousMessage)

ReferenceDistributionDiscreteMessage = _reflection.GeneratedProtocolMessageType('ReferenceDistributionDiscreteMessage', (_message.Message,), {
  'DESCRIPTOR' : _REFERENCEDISTRIBUTIONDISCRETEMESSAGE,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:ReferenceDistributionDiscreteMessage)
  })
_sym_db.RegisterMessage(ReferenceDistributionDiscreteMessage)

SummaryBetweenConstraintMsg = _reflection.GeneratedProtocolMessageType('SummaryBetweenConstraintMsg', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYBETWEENCONSTRAINTMSG,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:SummaryBetweenConstraintMsg)
  })
_sym_db.RegisterMessage(SummaryBetweenConstraintMsg)

ApplyFunctionMsg = _reflection.GeneratedProtocolMessageType('ApplyFunctionMsg', (_message.Message,), {
  'DESCRIPTOR' : _APPLYFUNCTIONMSG,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:ApplyFunctionMsg)
  })
_sym_db.RegisterMessage(ApplyFunctionMsg)

ValueConstraintMsg = _reflection.GeneratedProtocolMessageType('ValueConstraintMsg', (_message.Message,), {
  'DESCRIPTOR' : _VALUECONSTRAINTMSG,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:ValueConstraintMsg)
  })
_sym_db.RegisterMessage(ValueConstraintMsg)

MultiColumnValueConstraintMsg = _reflection.GeneratedProtocolMessageType('MultiColumnValueConstraintMsg', (_message.Message,), {
  'DESCRIPTOR' : _MULTICOLUMNVALUECONSTRAINTMSG,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:MultiColumnValueConstraintMsg)
  })
_sym_db.RegisterMessage(MultiColumnValueConstraintMsg)

ValueConstraintMsgs = _reflection.GeneratedProtocolMessageType('ValueConstraintMsgs', (_message.Message,), {
  'DESCRIPTOR' : _VALUECONSTRAINTMSGS,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:ValueConstraintMsgs)
  })
_sym_db.RegisterMessage(ValueConstraintMsgs)

SummaryConstraintMsgs = _reflection.GeneratedProtocolMessageType('SummaryConstraintMsgs', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYCONSTRAINTMSGS,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:SummaryConstraintMsgs)
  })
_sym_db.RegisterMessage(SummaryConstraintMsgs)

DatasetConstraintMsg = _reflection.GeneratedProtocolMessageType('DatasetConstraintMsg', (_message.Message,), {

  'ValueConstraintsEntry' : _reflection.GeneratedProtocolMessageType('ValueConstraintsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY,
    '__module__' : 'v0_constraints_pb2'
    # @@protoc_insertion_point(class_scope:DatasetConstraintMsg.ValueConstraintsEntry)
    })
  ,

  'SummaryConstraintsEntry' : _reflection.GeneratedProtocolMessageType('SummaryConstraintsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY,
    '__module__' : 'v0_constraints_pb2'
    # @@protoc_insertion_point(class_scope:DatasetConstraintMsg.SummaryConstraintsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETCONSTRAINTMSG,
  '__module__' : 'v0_constraints_pb2'
  # @@protoc_insertion_point(class_scope:DatasetConstraintMsg)
  })
_sym_db.RegisterMessage(DatasetConstraintMsg)
_sym_db.RegisterMessage(DatasetConstraintMsg.ValueConstraintsEntry)
_sym_db.RegisterMessage(DatasetConstraintMsg.SummaryConstraintsEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.whylogs.v0.core.constraintB\013ConstraintsP\001'
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._options = None
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._serialized_options = b'8\001'
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._options = None
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._serialized_options = b'8\001'
  _OP._serialized_start=2341
  _OP._serialized_end=2538
  _SUMMARYCONSTRAINTMSG._serialized_start=94
  _SUMMARYCONSTRAINTMSG._serialized_end=557
  _REFERENCEDISTRIBUTIONCONTINUOUSMESSAGE._serialized_start=559
  _REFERENCEDISTRIBUTIONCONTINUOUSMESSAGE._serialized_end=640
  _REFERENCEDISTRIBUTIONDISCRETEMESSAGE._serialized_start=643
  _REFERENCEDISTRIBUTIONDISCRETEMESSAGE._serialized_end=792
  _SUMMARYBETWEENCONSTRAINTMSG._serialized_start=795
  _SUMMARYBETWEENCONSTRAINTMSG._serialized_end=935
  _APPLYFUNCTIONMSG._serialized_start=937
  _APPLYFUNCTIONMSG._serialized_end=998
  _VALUECONSTRAINTMSG._serialized_start=1001
  _VALUECONSTRAINTMSG._serialized_end=1248
  _MULTICOLUMNVALUECONSTRAINTMSG._serialized_start=1251
  _MULTICOLUMNVALUECONSTRAINTMSG._serialized_end=1641
  _VALUECONSTRAINTMSGS._serialized_start=1644
  _VALUECONSTRAINTMSGS._serialized_end=1773
  _SUMMARYCONSTRAINTMSGS._serialized_start=1775
  _SUMMARYCONSTRAINTMSGS._serialized_end=1842
  _DATASETCONSTRAINTMSG._serialized_start=1845
  _DATASETCONSTRAINTMSG._serialized_end=2338
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._serialized_start=2178
  _DATASETCONSTRAINTMSG_VALUECONSTRAINTSENTRY._serialized_end=2255
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._serialized_start=2257
  _DATASETCONSTRAINTMSG_SUMMARYCONSTRAINTSENTRY._serialized_end=2338
# @@protoc_insertion_point(module_scope)
