# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v0_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11v0_messages.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x81\x01\n\nCountersV0\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12/\n\ntrue_count\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\nnull_count\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\"\x95\x01\n\x0cInferredType\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.InferredType.Type\x12\r\n\x05ratio\x18\x02 \x01(\x01\"T\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NULL\x10\x01\x12\x0e\n\nFRACTIONAL\x10\x02\x12\x0c\n\x08INTEGRAL\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\n\n\x06STRING\x10\x05\"F\n\x0e\x44oublesMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0b\n\x03min\x18\x02 \x01(\x01\x12\x0b\n\x03max\x18\x03 \x01(\x01\x12\x0b\n\x03sum\x18\x04 \x01(\x01\"D\n\x0cLongsMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0b\n\x03min\x18\x02 \x01(\x03\x12\x0b\n\x03max\x18\x03 \x01(\x03\x12\x0b\n\x03sum\x18\x04 \x01(\x03\";\n\x0fVarianceMessage\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0b\n\x03sum\x18\x02 \x01(\x01\x12\x0c\n\x04mean\x18\x03 \x01(\x01\"@\n\x1c\x46requentNumbersSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\x12\x10\n\x08lg_max_k\x18\x02 \x01(\x05\"@\n\x1c\x46requentItemsSketchMessageV0\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\x12\x10\n\x08lg_max_k\x18\x02 \x01(\x05\"\xf7\x01\n\x10NumbersMessageV0\x12\"\n\x08variance\x18\x01 \x01(\x0b\x32\x10.VarianceMessage\x12\"\n\x07\x64oubles\x18\x02 \x01(\x0b\x32\x0f.DoublesMessageH\x00\x12\x1e\n\x05longs\x18\x03 \x01(\x0b\x32\r.LongsMessageH\x00\x12\x11\n\thistogram\x18\x04 \x01(\x0c\x12\r\n\x05theta\x18\x05 \x01(\x0c\x12\x15\n\rcompact_theta\x18\x06 \x01(\x0c\x12\x37\n\x10\x66requent_numbers\x18\x07 \x01(\x0b\x32\x1d.FrequentNumbersSketchMessageB\t\n\x07numbers\"\xa0\x01\n\x0e\x43harPosMessage\x12\x11\n\tchar_list\x18\x01 \x01(\t\x12\x35\n\x0c\x63har_pos_map\x18\x02 \x03(\x0b\x32\x1f.CharPosMessage.CharPosMapEntry\x1a\x44\n\x0f\x43harPosMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.NumbersMessageV0:\x02\x38\x01\"\xcd\x01\n\x10StringsMessageV0\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\r\n\x05theta\x18\x02 \x01(\x0c\x12\r\n\x05items\x18\x03 \x01(\x0c\x12\x15\n\rcompact_theta\x18\x04 \x01(\x0c\x12!\n\x06length\x18\x05 \x01(\x0b\x32\x11.NumbersMessageV0\x12\'\n\x0ctoken_length\x18\x06 \x01(\x0b\x32\x11.NumbersMessageV0\x12)\n\x10\x63har_pos_tracker\x18\x07 \x01(\x0b\x32\x0f.CharPosMessage\"\xa0\x01\n\x0fSchemaMessageV0\x12\x34\n\ntypeCounts\x18\x01 \x03(\x0b\x32 .SchemaMessageV0.TypeCountsEntry\x12$\n\rinferred_type\x18\x02 \x01(\x0b\x32\r.InferredType\x1a\x31\n\x0fTypeCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xb7\x02\n\x0f\x43olumnMessageV0\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x08\x63ounters\x18\x02 \x01(\x0b\x32\x0b.CountersV0\x12 \n\x06schema\x18\x03 \x01(\x0b\x32\x10.SchemaMessageV0\x12\"\n\x07numbers\x18\x04 \x01(\x0b\x32\x11.NumbersMessageV0\x12\"\n\x07strings\x18\x05 \x01(\x0b\x32\x11.StringsMessageV0\x12$\n\rinferred_type\x18\x06 \x01(\x0b\x32\r.InferredType\x12\x35\n\x0e\x66requent_items\x18\x07 \x01(\x0b\x32\x1d.FrequentItemsSketchMessageV0\x12\x30\n\x13\x63\x61rdinality_tracker\x18\x08 \x01(\x0b\x32\x13.HllSketchMessageV0\"\xda\x02\n\x13\x44\x61tasetPropertiesV0\x12\x1c\n\x14schema_major_version\x18\x01 \x01(\r\x12\x1c\n\x14schema_minor_version\x18\x02 \x01(\r\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x19\n\x11session_timestamp\x18\x04 \x01(\x03\x12\x16\n\x0e\x64\x61ta_timestamp\x18\x05 \x01(\x03\x12,\n\x04tags\x18\x06 \x03(\x0b\x32\x1e.DatasetPropertiesV0.TagsEntry\x12\x34\n\x08metadata\x18\x07 \x03(\x0b\x32\".DatasetPropertiesV0.MetadataEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x12ScoreMatrixMessage\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x18\n\x10prediction_field\x18\x02 \x01(\t\x12\x14\n\x0ctarget_field\x18\x03 \x01(\t\x12\x13\n\x0bscore_field\x18\x04 \x01(\t\x12!\n\x06scores\x18\n \x03(\x0b\x32\x11.NumbersMessageV0\"\x94\x01\n\x18RegressionMetricsMessage\x12\x18\n\x10prediction_field\x18\x01 \x01(\t\x12\x14\n\x0ctarget_field\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12\x14\n\x0csum_abs_diff\x18\x04 \x01(\x01\x12\x10\n\x08sum_diff\x18\x05 \x01(\x01\x12\x11\n\tsum2_diff\x18\x06 \x01(\x01\"\x94\x01\n\x13ModelMetricsMessage\x12(\n\x0bscoreMatrix\x18\x01 \x01(\x0b\x32\x13.ScoreMatrixMessage\x12\x1d\n\tmodelType\x18\x02 \x01(\x0e\x32\n.ModelType\x12\x34\n\x11regressionMetrics\x18\x03 \x01(\x0b\x32\x19.RegressionMetricsMessage\"S\n\x13ModelProfileMessage\x12\x15\n\routput_fields\x18\x01 \x03(\t\x12%\n\x07metrics\x18\n \x01(\x0b\x32\x14.ModelMetricsMessage\"\xe8\x01\n\x17\x44\x61tasetProfileMessageV0\x12(\n\nproperties\x18\x01 \x01(\x0b\x32\x14.DatasetPropertiesV0\x12\x36\n\x07\x63olumns\x18\x02 \x03(\x0b\x32%.DatasetProfileMessageV0.ColumnsEntry\x12)\n\x0bmodeProfile\x18\n \x01(\x0b\x32\x14.ModelProfileMessage\x1a@\n\x0c\x43olumnsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.ColumnMessageV0:\x02\x38\x01\"H\n\x13\x43olumnsChunkSegment\x12\x0e\n\x06marker\x18\x01 \x01(\t\x12!\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x10.ColumnMessageV0\"R\n\x16\x44\x61tasetMetadataSegment\x12\x0e\n\x06marker\x18\x01 \x01(\t\x12(\n\nproperties\x18\x02 \x01(\x0b\x32\x14.DatasetPropertiesV0\"~\n\x0eMessageSegment\x12\x0e\n\x06marker\x18\x01 \x01(\t\x12+\n\x08metadata\x18\x02 \x01(\x0b\x32\x17.DatasetMetadataSegmentH\x00\x12\'\n\x07\x63olumns\x18\x03 \x01(\x0b\x32\x14.ColumnsChunkSegmentH\x00\x42\x06\n\x04item\"2\n\x12HllSketchMessageV0\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\x12\x0c\n\x04lg_k\x18\x02 \x01(\x05\"6\n\x16KllFloatsSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\x12\x0c\n\x04lg_k\x18\x02 \x01(\x05*U\n\tModelType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x43LASSIFICATION\x10\x01\x12\x0e\n\nREGRESSION\x10\x02\x12\x0e\n\nEMBEDDINGS\x10\x03\x12\x07\n\x03NLP\x10\x04\x42)\n\x1b\x63om.whylogs.v0.core.messageB\x08MessagesP\x01\x62\x06proto3')

_MODELTYPE = DESCRIPTOR.enum_types_by_name['ModelType']
ModelType = enum_type_wrapper.EnumTypeWrapper(_MODELTYPE)
UNKNOWN = 0
CLASSIFICATION = 1
REGRESSION = 2
EMBEDDINGS = 3
NLP = 4


_COUNTERSV0 = DESCRIPTOR.message_types_by_name['CountersV0']
_INFERREDTYPE = DESCRIPTOR.message_types_by_name['InferredType']
_DOUBLESMESSAGE = DESCRIPTOR.message_types_by_name['DoublesMessage']
_LONGSMESSAGE = DESCRIPTOR.message_types_by_name['LongsMessage']
_VARIANCEMESSAGE = DESCRIPTOR.message_types_by_name['VarianceMessage']
_FREQUENTNUMBERSSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['FrequentNumbersSketchMessage']
_FREQUENTITEMSSKETCHMESSAGEV0 = DESCRIPTOR.message_types_by_name['FrequentItemsSketchMessageV0']
_NUMBERSMESSAGEV0 = DESCRIPTOR.message_types_by_name['NumbersMessageV0']
_CHARPOSMESSAGE = DESCRIPTOR.message_types_by_name['CharPosMessage']
_CHARPOSMESSAGE_CHARPOSMAPENTRY = _CHARPOSMESSAGE.nested_types_by_name['CharPosMapEntry']
_STRINGSMESSAGEV0 = DESCRIPTOR.message_types_by_name['StringsMessageV0']
_SCHEMAMESSAGEV0 = DESCRIPTOR.message_types_by_name['SchemaMessageV0']
_SCHEMAMESSAGEV0_TYPECOUNTSENTRY = _SCHEMAMESSAGEV0.nested_types_by_name['TypeCountsEntry']
_COLUMNMESSAGEV0 = DESCRIPTOR.message_types_by_name['ColumnMessageV0']
_DATASETPROPERTIESV0 = DESCRIPTOR.message_types_by_name['DatasetPropertiesV0']
_DATASETPROPERTIESV0_TAGSENTRY = _DATASETPROPERTIESV0.nested_types_by_name['TagsEntry']
_DATASETPROPERTIESV0_METADATAENTRY = _DATASETPROPERTIESV0.nested_types_by_name['MetadataEntry']
_SCOREMATRIXMESSAGE = DESCRIPTOR.message_types_by_name['ScoreMatrixMessage']
_REGRESSIONMETRICSMESSAGE = DESCRIPTOR.message_types_by_name['RegressionMetricsMessage']
_MODELMETRICSMESSAGE = DESCRIPTOR.message_types_by_name['ModelMetricsMessage']
_MODELPROFILEMESSAGE = DESCRIPTOR.message_types_by_name['ModelProfileMessage']
_DATASETPROFILEMESSAGEV0 = DESCRIPTOR.message_types_by_name['DatasetProfileMessageV0']
_DATASETPROFILEMESSAGEV0_COLUMNSENTRY = _DATASETPROFILEMESSAGEV0.nested_types_by_name['ColumnsEntry']
_COLUMNSCHUNKSEGMENT = DESCRIPTOR.message_types_by_name['ColumnsChunkSegment']
_DATASETMETADATASEGMENT = DESCRIPTOR.message_types_by_name['DatasetMetadataSegment']
_MESSAGESEGMENT = DESCRIPTOR.message_types_by_name['MessageSegment']
_HLLSKETCHMESSAGEV0 = DESCRIPTOR.message_types_by_name['HllSketchMessageV0']
_KLLFLOATSSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['KllFloatsSketchMessage']
_INFERREDTYPE_TYPE = _INFERREDTYPE.enum_types_by_name['Type']
CountersV0 = _reflection.GeneratedProtocolMessageType('CountersV0', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERSV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:CountersV0)
  })
_sym_db.RegisterMessage(CountersV0)

InferredType = _reflection.GeneratedProtocolMessageType('InferredType', (_message.Message,), {
  'DESCRIPTOR' : _INFERREDTYPE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:InferredType)
  })
_sym_db.RegisterMessage(InferredType)

DoublesMessage = _reflection.GeneratedProtocolMessageType('DoublesMessage', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLESMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:DoublesMessage)
  })
_sym_db.RegisterMessage(DoublesMessage)

LongsMessage = _reflection.GeneratedProtocolMessageType('LongsMessage', (_message.Message,), {
  'DESCRIPTOR' : _LONGSMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:LongsMessage)
  })
_sym_db.RegisterMessage(LongsMessage)

VarianceMessage = _reflection.GeneratedProtocolMessageType('VarianceMessage', (_message.Message,), {
  'DESCRIPTOR' : _VARIANCEMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:VarianceMessage)
  })
_sym_db.RegisterMessage(VarianceMessage)

FrequentNumbersSketchMessage = _reflection.GeneratedProtocolMessageType('FrequentNumbersSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _FREQUENTNUMBERSSKETCHMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:FrequentNumbersSketchMessage)
  })
_sym_db.RegisterMessage(FrequentNumbersSketchMessage)

FrequentItemsSketchMessageV0 = _reflection.GeneratedProtocolMessageType('FrequentItemsSketchMessageV0', (_message.Message,), {
  'DESCRIPTOR' : _FREQUENTITEMSSKETCHMESSAGEV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:FrequentItemsSketchMessageV0)
  })
_sym_db.RegisterMessage(FrequentItemsSketchMessageV0)

NumbersMessageV0 = _reflection.GeneratedProtocolMessageType('NumbersMessageV0', (_message.Message,), {
  'DESCRIPTOR' : _NUMBERSMESSAGEV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:NumbersMessageV0)
  })
_sym_db.RegisterMessage(NumbersMessageV0)

CharPosMessage = _reflection.GeneratedProtocolMessageType('CharPosMessage', (_message.Message,), {

  'CharPosMapEntry' : _reflection.GeneratedProtocolMessageType('CharPosMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHARPOSMESSAGE_CHARPOSMAPENTRY,
    '__module__' : 'v0_messages_pb2'
    # @@protoc_insertion_point(class_scope:CharPosMessage.CharPosMapEntry)
    })
  ,
  'DESCRIPTOR' : _CHARPOSMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:CharPosMessage)
  })
_sym_db.RegisterMessage(CharPosMessage)
_sym_db.RegisterMessage(CharPosMessage.CharPosMapEntry)

StringsMessageV0 = _reflection.GeneratedProtocolMessageType('StringsMessageV0', (_message.Message,), {
  'DESCRIPTOR' : _STRINGSMESSAGEV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:StringsMessageV0)
  })
_sym_db.RegisterMessage(StringsMessageV0)

SchemaMessageV0 = _reflection.GeneratedProtocolMessageType('SchemaMessageV0', (_message.Message,), {

  'TypeCountsEntry' : _reflection.GeneratedProtocolMessageType('TypeCountsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMAMESSAGEV0_TYPECOUNTSENTRY,
    '__module__' : 'v0_messages_pb2'
    # @@protoc_insertion_point(class_scope:SchemaMessageV0.TypeCountsEntry)
    })
  ,
  'DESCRIPTOR' : _SCHEMAMESSAGEV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:SchemaMessageV0)
  })
_sym_db.RegisterMessage(SchemaMessageV0)
_sym_db.RegisterMessage(SchemaMessageV0.TypeCountsEntry)

ColumnMessageV0 = _reflection.GeneratedProtocolMessageType('ColumnMessageV0', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNMESSAGEV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:ColumnMessageV0)
  })
_sym_db.RegisterMessage(ColumnMessageV0)

DatasetPropertiesV0 = _reflection.GeneratedProtocolMessageType('DatasetPropertiesV0', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROPERTIESV0_TAGSENTRY,
    '__module__' : 'v0_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetPropertiesV0.TagsEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROPERTIESV0_METADATAENTRY,
    '__module__' : 'v0_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetPropertiesV0.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETPROPERTIESV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetPropertiesV0)
  })
_sym_db.RegisterMessage(DatasetPropertiesV0)
_sym_db.RegisterMessage(DatasetPropertiesV0.TagsEntry)
_sym_db.RegisterMessage(DatasetPropertiesV0.MetadataEntry)

ScoreMatrixMessage = _reflection.GeneratedProtocolMessageType('ScoreMatrixMessage', (_message.Message,), {
  'DESCRIPTOR' : _SCOREMATRIXMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:ScoreMatrixMessage)
  })
_sym_db.RegisterMessage(ScoreMatrixMessage)

RegressionMetricsMessage = _reflection.GeneratedProtocolMessageType('RegressionMetricsMessage', (_message.Message,), {
  'DESCRIPTOR' : _REGRESSIONMETRICSMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:RegressionMetricsMessage)
  })
_sym_db.RegisterMessage(RegressionMetricsMessage)

ModelMetricsMessage = _reflection.GeneratedProtocolMessageType('ModelMetricsMessage', (_message.Message,), {
  'DESCRIPTOR' : _MODELMETRICSMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:ModelMetricsMessage)
  })
_sym_db.RegisterMessage(ModelMetricsMessage)

ModelProfileMessage = _reflection.GeneratedProtocolMessageType('ModelProfileMessage', (_message.Message,), {
  'DESCRIPTOR' : _MODELPROFILEMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:ModelProfileMessage)
  })
_sym_db.RegisterMessage(ModelProfileMessage)

DatasetProfileMessageV0 = _reflection.GeneratedProtocolMessageType('DatasetProfileMessageV0', (_message.Message,), {

  'ColumnsEntry' : _reflection.GeneratedProtocolMessageType('ColumnsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROFILEMESSAGEV0_COLUMNSENTRY,
    '__module__' : 'v0_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProfileMessageV0.ColumnsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETPROFILEMESSAGEV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetProfileMessageV0)
  })
_sym_db.RegisterMessage(DatasetProfileMessageV0)
_sym_db.RegisterMessage(DatasetProfileMessageV0.ColumnsEntry)

ColumnsChunkSegment = _reflection.GeneratedProtocolMessageType('ColumnsChunkSegment', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSCHUNKSEGMENT,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:ColumnsChunkSegment)
  })
_sym_db.RegisterMessage(ColumnsChunkSegment)

DatasetMetadataSegment = _reflection.GeneratedProtocolMessageType('DatasetMetadataSegment', (_message.Message,), {
  'DESCRIPTOR' : _DATASETMETADATASEGMENT,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetMetadataSegment)
  })
_sym_db.RegisterMessage(DatasetMetadataSegment)

MessageSegment = _reflection.GeneratedProtocolMessageType('MessageSegment', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGESEGMENT,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:MessageSegment)
  })
_sym_db.RegisterMessage(MessageSegment)

HllSketchMessageV0 = _reflection.GeneratedProtocolMessageType('HllSketchMessageV0', (_message.Message,), {
  'DESCRIPTOR' : _HLLSKETCHMESSAGEV0,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:HllSketchMessageV0)
  })
_sym_db.RegisterMessage(HllSketchMessageV0)

KllFloatsSketchMessage = _reflection.GeneratedProtocolMessageType('KllFloatsSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _KLLFLOATSSKETCHMESSAGE,
  '__module__' : 'v0_messages_pb2'
  # @@protoc_insertion_point(class_scope:KllFloatsSketchMessage)
  })
_sym_db.RegisterMessage(KllFloatsSketchMessage)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.whylogs.v0.core.messageB\010MessagesP\001'
  _COUNTERSV0.fields_by_name['null_count']._options = None
  _COUNTERSV0.fields_by_name['null_count']._serialized_options = b'\030\001'
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._options = None
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._serialized_options = b'8\001'
  _SCHEMAMESSAGEV0_TYPECOUNTSENTRY._options = None
  _SCHEMAMESSAGEV0_TYPECOUNTSENTRY._serialized_options = b'8\001'
  _DATASETPROPERTIESV0_TAGSENTRY._options = None
  _DATASETPROPERTIESV0_TAGSENTRY._serialized_options = b'8\001'
  _DATASETPROPERTIESV0_METADATAENTRY._options = None
  _DATASETPROPERTIESV0_METADATAENTRY._serialized_options = b'8\001'
  _DATASETPROFILEMESSAGEV0_COLUMNSENTRY._options = None
  _DATASETPROFILEMESSAGEV0_COLUMNSENTRY._serialized_options = b'8\001'
  _MODELTYPE._serialized_start=3278
  _MODELTYPE._serialized_end=3363
  _COUNTERSV0._serialized_start=54
  _COUNTERSV0._serialized_end=183
  _INFERREDTYPE._serialized_start=186
  _INFERREDTYPE._serialized_end=335
  _INFERREDTYPE_TYPE._serialized_start=251
  _INFERREDTYPE_TYPE._serialized_end=335
  _DOUBLESMESSAGE._serialized_start=337
  _DOUBLESMESSAGE._serialized_end=407
  _LONGSMESSAGE._serialized_start=409
  _LONGSMESSAGE._serialized_end=477
  _VARIANCEMESSAGE._serialized_start=479
  _VARIANCEMESSAGE._serialized_end=538
  _FREQUENTNUMBERSSKETCHMESSAGE._serialized_start=540
  _FREQUENTNUMBERSSKETCHMESSAGE._serialized_end=604
  _FREQUENTITEMSSKETCHMESSAGEV0._serialized_start=606
  _FREQUENTITEMSSKETCHMESSAGEV0._serialized_end=670
  _NUMBERSMESSAGEV0._serialized_start=673
  _NUMBERSMESSAGEV0._serialized_end=920
  _CHARPOSMESSAGE._serialized_start=923
  _CHARPOSMESSAGE._serialized_end=1083
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._serialized_start=1015
  _CHARPOSMESSAGE_CHARPOSMAPENTRY._serialized_end=1083
  _STRINGSMESSAGEV0._serialized_start=1086
  _STRINGSMESSAGEV0._serialized_end=1291
  _SCHEMAMESSAGEV0._serialized_start=1294
  _SCHEMAMESSAGEV0._serialized_end=1454
  _SCHEMAMESSAGEV0_TYPECOUNTSENTRY._serialized_start=1405
  _SCHEMAMESSAGEV0_TYPECOUNTSENTRY._serialized_end=1454
  _COLUMNMESSAGEV0._serialized_start=1457
  _COLUMNMESSAGEV0._serialized_end=1768
  _DATASETPROPERTIESV0._serialized_start=1771
  _DATASETPROPERTIESV0._serialized_end=2117
  _DATASETPROPERTIESV0_TAGSENTRY._serialized_start=2025
  _DATASETPROPERTIESV0_TAGSENTRY._serialized_end=2068
  _DATASETPROPERTIESV0_METADATAENTRY._serialized_start=2070
  _DATASETPROPERTIESV0_METADATAENTRY._serialized_end=2117
  _SCOREMATRIXMESSAGE._serialized_start=2120
  _SCOREMATRIXMESSAGE._serialized_end=2260
  _REGRESSIONMETRICSMESSAGE._serialized_start=2263
  _REGRESSIONMETRICSMESSAGE._serialized_end=2411
  _MODELMETRICSMESSAGE._serialized_start=2414
  _MODELMETRICSMESSAGE._serialized_end=2562
  _MODELPROFILEMESSAGE._serialized_start=2564
  _MODELPROFILEMESSAGE._serialized_end=2647
  _DATASETPROFILEMESSAGEV0._serialized_start=2650
  _DATASETPROFILEMESSAGEV0._serialized_end=2882
  _DATASETPROFILEMESSAGEV0_COLUMNSENTRY._serialized_start=2818
  _DATASETPROFILEMESSAGEV0_COLUMNSENTRY._serialized_end=2882
  _COLUMNSCHUNKSEGMENT._serialized_start=2884
  _COLUMNSCHUNKSEGMENT._serialized_end=2956
  _DATASETMETADATASEGMENT._serialized_start=2958
  _DATASETMETADATASEGMENT._serialized_end=3040
  _MESSAGESEGMENT._serialized_start=3042
  _MESSAGESEGMENT._serialized_end=3168
  _HLLSKETCHMESSAGEV0._serialized_start=3170
  _HLLSKETCHMESSAGEV0._serialized_end=3220
  _KLLFLOATSSKETCHMESSAGE._serialized_start=3222
  _KLLFLOATSSKETCHMESSAGE._serialized_end=3276
# @@protoc_insertion_point(module_scope)
