# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: whylogs_messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16whylogs_messages.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"~\n\x08\x44\x61taType\x12\x1c\n\x04type\x18\x01 \x01(\x0e\x32\x0e.DataType.Type\"T\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NULL\x10\x01\x12\x0e\n\nFRACTIONAL\x10\x02\x12\x0c\n\x08INTEGRAL\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\n\n\x06STRING\x10\x05\"\"\n\x10HllSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\",\n\x1a\x46requentItemsSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\"\"\n\x10KllSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\"\"\n\x10\x43pcSketchMessage\x12\x0e\n\x06sketch\x18\x01 \x01(\x0c\"\xde\x02\n\x16MetricComponentMessage\x12\x0f\n\x07type_id\x18\x01 \x01(\r\x12\x0b\n\x01n\x18\x02 \x01(\x03H\x00\x12\x0b\n\x01\x64\x18\x03 \x01(\x01H\x00\x12\x35\n\x0e\x66requent_items\x18\x04 \x01(\x0b\x32\x1b.FrequentItemsSketchMessageH\x00\x12 \n\x03hll\x18\x05 \x01(\x0b\x32\x11.HllSketchMessageH\x00\x12 \n\x03kll\x18\x06 \x01(\x0b\x32\x11.KllSketchMessageH\x00\x12 \n\x03\x63pc\x18\x07 \x01(\x0b\x32\x11.CpcSketchMessageH\x00\x12\x1a\n\x10serialized_bytes\x18\n \x01(\x0cH\x00\x12\x32\n\x0f\x64\x61taclass_param\x18\x0b \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12#\n\x03msg\x18\x0c \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\x07\n\x05value\"\xa2\x01\n\rMetricMessage\x12?\n\x11metric_components\x18\x01 \x03(\x0b\x32$.MetricMessage.MetricComponentsEntry\x1aP\n\x15MetricComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.MetricComponentMessage:\x02\x38\x01\"\xa2\x01\n\rColumnMessage\x12?\n\x11metric_components\x18\x01 \x03(\x0b\x32$.ColumnMessage.MetricComponentsEntry\x1aP\n\x15MetricComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.MetricComponentMessage:\x02\x38\x01\"\xc4\x02\n\x11\x44\x61tasetProperties\x12\x1c\n\x14schema_major_version\x18\x01 \x01(\r\x12\x1c\n\x14schema_minor_version\x18\x02 \x01(\r\x12\x1a\n\x12\x63reation_timestamp\x18\x04 \x01(\x04\x12\x19\n\x11\x64\x61taset_timestamp\x18\x05 \x01(\x04\x12*\n\x04tags\x18\x06 \x03(\x0b\x32\x1c.DatasetProperties.TagsEntry\x12\x32\n\x08metadata\x18\x07 \x03(\x0b\x32 .DatasetProperties.MetadataEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1f\n\x0c\x43hunkOffsets\x12\x0f\n\x07offsets\x18\x01 \x03(\x04\"\xa0\x01\n\x0c\x43hunkMessage\x12>\n\x11metric_components\x18\x01 \x03(\x0b\x32#.ChunkMessage.MetricComponentsEntry\x1aP\n\x15MetricComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.MetricComponentMessage:\x02\x38\x01\"v\n\x0b\x43hunkHeader\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.ChunkHeader.ChunkType\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\r\"$\n\tChunkType\x12\x0b\n\x07\x44\x41TASET\x10\x00\x12\n\n\x06\x43OLUMN\x10\x02\"\x84\x03\n\x14\x44\x61tasetProfileHeader\x12&\n\nproperties\x18\x01 \x01(\x0b\x32\x12.DatasetProperties\x12@\n\x0e\x63olumn_offsets\x18\x02 \x03(\x0b\x32(.DatasetProfileHeader.ColumnOffsetsEntry\x12%\n\x0emetric_offsets\x18\x03 \x03(\x0b\x32\r.ChunkOffsets\x12\x0e\n\x06length\x18\x04 \x01(\x04\x12K\n\x14indexed_metric_paths\x18\x05 \x03(\x0b\x32-.DatasetProfileHeader.IndexedMetricPathsEntry\x1a\x43\n\x12\x43olumnOffsetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1c\n\x05value\x18\x02 \x01(\x0b\x32\r.ChunkOffsets:\x02\x38\x01\x1a\x39\n\x17IndexedMetricPathsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"(\n\nSegmentTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\":\n\x07Segment\x12\x19\n\x04tags\x18\x01 \x03(\x0b\x32\x0b.SegmentTag\x12\x14\n\x0cpartition_id\x18\x02 \x01(\t\"1\n\x15SegmentationPartition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\xad\x01\n\x14\x44\x61tasetSegmentHeader\x12\x14\n\x0chas_segments\x18\x01 \x01(\x08\x12\x1a\n\x08segments\x18\x04 \x03(\x0b\x32\x08.Segment\x12\x33\n\x07offsets\x18\x05 \x03(\x0b\x32\".DatasetSegmentHeader.OffsetsEntry\x1a.\n\x0cOffsetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x42&\n\x18\x63om.whylogs.core.messageB\x08MessagesP\x01\x62\x06proto3')



_DATATYPE = DESCRIPTOR.message_types_by_name['DataType']
_HLLSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['HllSketchMessage']
_FREQUENTITEMSSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['FrequentItemsSketchMessage']
_KLLSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['KllSketchMessage']
_CPCSKETCHMESSAGE = DESCRIPTOR.message_types_by_name['CpcSketchMessage']
_METRICCOMPONENTMESSAGE = DESCRIPTOR.message_types_by_name['MetricComponentMessage']
_METRICMESSAGE = DESCRIPTOR.message_types_by_name['MetricMessage']
_METRICMESSAGE_METRICCOMPONENTSENTRY = _METRICMESSAGE.nested_types_by_name['MetricComponentsEntry']
_COLUMNMESSAGE = DESCRIPTOR.message_types_by_name['ColumnMessage']
_COLUMNMESSAGE_METRICCOMPONENTSENTRY = _COLUMNMESSAGE.nested_types_by_name['MetricComponentsEntry']
_DATASETPROPERTIES = DESCRIPTOR.message_types_by_name['DatasetProperties']
_DATASETPROPERTIES_TAGSENTRY = _DATASETPROPERTIES.nested_types_by_name['TagsEntry']
_DATASETPROPERTIES_METADATAENTRY = _DATASETPROPERTIES.nested_types_by_name['MetadataEntry']
_CHUNKOFFSETS = DESCRIPTOR.message_types_by_name['ChunkOffsets']
_CHUNKMESSAGE = DESCRIPTOR.message_types_by_name['ChunkMessage']
_CHUNKMESSAGE_METRICCOMPONENTSENTRY = _CHUNKMESSAGE.nested_types_by_name['MetricComponentsEntry']
_CHUNKHEADER = DESCRIPTOR.message_types_by_name['ChunkHeader']
_DATASETPROFILEHEADER = DESCRIPTOR.message_types_by_name['DatasetProfileHeader']
_DATASETPROFILEHEADER_COLUMNOFFSETSENTRY = _DATASETPROFILEHEADER.nested_types_by_name['ColumnOffsetsEntry']
_DATASETPROFILEHEADER_INDEXEDMETRICPATHSENTRY = _DATASETPROFILEHEADER.nested_types_by_name['IndexedMetricPathsEntry']
_SEGMENTTAG = DESCRIPTOR.message_types_by_name['SegmentTag']
_SEGMENT = DESCRIPTOR.message_types_by_name['Segment']
_SEGMENTATIONPARTITION = DESCRIPTOR.message_types_by_name['SegmentationPartition']
_DATASETSEGMENTHEADER = DESCRIPTOR.message_types_by_name['DatasetSegmentHeader']
_DATASETSEGMENTHEADER_OFFSETSENTRY = _DATASETSEGMENTHEADER.nested_types_by_name['OffsetsEntry']
_DATATYPE_TYPE = _DATATYPE.enum_types_by_name['Type']
_CHUNKHEADER_CHUNKTYPE = _CHUNKHEADER.enum_types_by_name['ChunkType']
DataType = _reflection.GeneratedProtocolMessageType('DataType', (_message.Message,), {
  'DESCRIPTOR' : _DATATYPE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:DataType)
  })
_sym_db.RegisterMessage(DataType)

HllSketchMessage = _reflection.GeneratedProtocolMessageType('HllSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _HLLSKETCHMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:HllSketchMessage)
  })
_sym_db.RegisterMessage(HllSketchMessage)

FrequentItemsSketchMessage = _reflection.GeneratedProtocolMessageType('FrequentItemsSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _FREQUENTITEMSSKETCHMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:FrequentItemsSketchMessage)
  })
_sym_db.RegisterMessage(FrequentItemsSketchMessage)

KllSketchMessage = _reflection.GeneratedProtocolMessageType('KllSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _KLLSKETCHMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:KllSketchMessage)
  })
_sym_db.RegisterMessage(KllSketchMessage)

CpcSketchMessage = _reflection.GeneratedProtocolMessageType('CpcSketchMessage', (_message.Message,), {
  'DESCRIPTOR' : _CPCSKETCHMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:CpcSketchMessage)
  })
_sym_db.RegisterMessage(CpcSketchMessage)

MetricComponentMessage = _reflection.GeneratedProtocolMessageType('MetricComponentMessage', (_message.Message,), {
  'DESCRIPTOR' : _METRICCOMPONENTMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:MetricComponentMessage)
  })
_sym_db.RegisterMessage(MetricComponentMessage)

MetricMessage = _reflection.GeneratedProtocolMessageType('MetricMessage', (_message.Message,), {

  'MetricComponentsEntry' : _reflection.GeneratedProtocolMessageType('MetricComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICMESSAGE_METRICCOMPONENTSENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:MetricMessage.MetricComponentsEntry)
    })
  ,
  'DESCRIPTOR' : _METRICMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:MetricMessage)
  })
_sym_db.RegisterMessage(MetricMessage)
_sym_db.RegisterMessage(MetricMessage.MetricComponentsEntry)

ColumnMessage = _reflection.GeneratedProtocolMessageType('ColumnMessage', (_message.Message,), {

  'MetricComponentsEntry' : _reflection.GeneratedProtocolMessageType('MetricComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _COLUMNMESSAGE_METRICCOMPONENTSENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:ColumnMessage.MetricComponentsEntry)
    })
  ,
  'DESCRIPTOR' : _COLUMNMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:ColumnMessage)
  })
_sym_db.RegisterMessage(ColumnMessage)
_sym_db.RegisterMessage(ColumnMessage.MetricComponentsEntry)

DatasetProperties = _reflection.GeneratedProtocolMessageType('DatasetProperties', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROPERTIES_TAGSENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProperties.TagsEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROPERTIES_METADATAENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProperties.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETPROPERTIES,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetProperties)
  })
_sym_db.RegisterMessage(DatasetProperties)
_sym_db.RegisterMessage(DatasetProperties.TagsEntry)
_sym_db.RegisterMessage(DatasetProperties.MetadataEntry)

ChunkOffsets = _reflection.GeneratedProtocolMessageType('ChunkOffsets', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKOFFSETS,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:ChunkOffsets)
  })
_sym_db.RegisterMessage(ChunkOffsets)

ChunkMessage = _reflection.GeneratedProtocolMessageType('ChunkMessage', (_message.Message,), {

  'MetricComponentsEntry' : _reflection.GeneratedProtocolMessageType('MetricComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHUNKMESSAGE_METRICCOMPONENTSENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:ChunkMessage.MetricComponentsEntry)
    })
  ,
  'DESCRIPTOR' : _CHUNKMESSAGE,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:ChunkMessage)
  })
_sym_db.RegisterMessage(ChunkMessage)
_sym_db.RegisterMessage(ChunkMessage.MetricComponentsEntry)

ChunkHeader = _reflection.GeneratedProtocolMessageType('ChunkHeader', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKHEADER,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:ChunkHeader)
  })
_sym_db.RegisterMessage(ChunkHeader)

DatasetProfileHeader = _reflection.GeneratedProtocolMessageType('DatasetProfileHeader', (_message.Message,), {

  'ColumnOffsetsEntry' : _reflection.GeneratedProtocolMessageType('ColumnOffsetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROFILEHEADER_COLUMNOFFSETSENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProfileHeader.ColumnOffsetsEntry)
    })
  ,

  'IndexedMetricPathsEntry' : _reflection.GeneratedProtocolMessageType('IndexedMetricPathsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETPROFILEHEADER_INDEXEDMETRICPATHSENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetProfileHeader.IndexedMetricPathsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETPROFILEHEADER,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetProfileHeader)
  })
_sym_db.RegisterMessage(DatasetProfileHeader)
_sym_db.RegisterMessage(DatasetProfileHeader.ColumnOffsetsEntry)
_sym_db.RegisterMessage(DatasetProfileHeader.IndexedMetricPathsEntry)

SegmentTag = _reflection.GeneratedProtocolMessageType('SegmentTag', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTTAG,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:SegmentTag)
  })
_sym_db.RegisterMessage(SegmentTag)

Segment = _reflection.GeneratedProtocolMessageType('Segment', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENT,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:Segment)
  })
_sym_db.RegisterMessage(Segment)

SegmentationPartition = _reflection.GeneratedProtocolMessageType('SegmentationPartition', (_message.Message,), {
  'DESCRIPTOR' : _SEGMENTATIONPARTITION,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:SegmentationPartition)
  })
_sym_db.RegisterMessage(SegmentationPartition)

DatasetSegmentHeader = _reflection.GeneratedProtocolMessageType('DatasetSegmentHeader', (_message.Message,), {

  'OffsetsEntry' : _reflection.GeneratedProtocolMessageType('OffsetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASETSEGMENTHEADER_OFFSETSENTRY,
    '__module__' : 'whylogs_messages_pb2'
    # @@protoc_insertion_point(class_scope:DatasetSegmentHeader.OffsetsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASETSEGMENTHEADER,
  '__module__' : 'whylogs_messages_pb2'
  # @@protoc_insertion_point(class_scope:DatasetSegmentHeader)
  })
_sym_db.RegisterMessage(DatasetSegmentHeader)
_sym_db.RegisterMessage(DatasetSegmentHeader.OffsetsEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.whylogs.core.messageB\010MessagesP\001'
  _METRICMESSAGE_METRICCOMPONENTSENTRY._options = None
  _METRICMESSAGE_METRICCOMPONENTSENTRY._serialized_options = b'8\001'
  _COLUMNMESSAGE_METRICCOMPONENTSENTRY._options = None
  _COLUMNMESSAGE_METRICCOMPONENTSENTRY._serialized_options = b'8\001'
  _DATASETPROPERTIES_TAGSENTRY._options = None
  _DATASETPROPERTIES_TAGSENTRY._serialized_options = b'8\001'
  _DATASETPROPERTIES_METADATAENTRY._options = None
  _DATASETPROPERTIES_METADATAENTRY._serialized_options = b'8\001'
  _CHUNKMESSAGE_METRICCOMPONENTSENTRY._options = None
  _CHUNKMESSAGE_METRICCOMPONENTSENTRY._serialized_options = b'8\001'
  _DATASETPROFILEHEADER_COLUMNOFFSETSENTRY._options = None
  _DATASETPROFILEHEADER_COLUMNOFFSETSENTRY._serialized_options = b'8\001'
  _DATASETPROFILEHEADER_INDEXEDMETRICPATHSENTRY._options = None
  _DATASETPROFILEHEADER_INDEXEDMETRICPATHSENTRY._serialized_options = b'8\001'
  _DATASETSEGMENTHEADER_OFFSETSENTRY._options = None
  _DATASETSEGMENTHEADER_OFFSETSENTRY._serialized_options = b'8\001'
  _DATATYPE._serialized_start=83
  _DATATYPE._serialized_end=209
  _DATATYPE_TYPE._serialized_start=125
  _DATATYPE_TYPE._serialized_end=209
  _HLLSKETCHMESSAGE._serialized_start=211
  _HLLSKETCHMESSAGE._serialized_end=245
  _FREQUENTITEMSSKETCHMESSAGE._serialized_start=247
  _FREQUENTITEMSSKETCHMESSAGE._serialized_end=291
  _KLLSKETCHMESSAGE._serialized_start=293
  _KLLSKETCHMESSAGE._serialized_end=327
  _CPCSKETCHMESSAGE._serialized_start=329
  _CPCSKETCHMESSAGE._serialized_end=363
  _METRICCOMPONENTMESSAGE._serialized_start=366
  _METRICCOMPONENTMESSAGE._serialized_end=716
  _METRICMESSAGE._serialized_start=719
  _METRICMESSAGE._serialized_end=881
  _METRICMESSAGE_METRICCOMPONENTSENTRY._serialized_start=801
  _METRICMESSAGE_METRICCOMPONENTSENTRY._serialized_end=881
  _COLUMNMESSAGE._serialized_start=884
  _COLUMNMESSAGE._serialized_end=1046
  _COLUMNMESSAGE_METRICCOMPONENTSENTRY._serialized_start=801
  _COLUMNMESSAGE_METRICCOMPONENTSENTRY._serialized_end=881
  _DATASETPROPERTIES._serialized_start=1049
  _DATASETPROPERTIES._serialized_end=1373
  _DATASETPROPERTIES_TAGSENTRY._serialized_start=1281
  _DATASETPROPERTIES_TAGSENTRY._serialized_end=1324
  _DATASETPROPERTIES_METADATAENTRY._serialized_start=1326
  _DATASETPROPERTIES_METADATAENTRY._serialized_end=1373
  _CHUNKOFFSETS._serialized_start=1375
  _CHUNKOFFSETS._serialized_end=1406
  _CHUNKMESSAGE._serialized_start=1409
  _CHUNKMESSAGE._serialized_end=1569
  _CHUNKMESSAGE_METRICCOMPONENTSENTRY._serialized_start=1489
  _CHUNKMESSAGE_METRICCOMPONENTSENTRY._serialized_end=1569
  _CHUNKHEADER._serialized_start=1571
  _CHUNKHEADER._serialized_end=1689
  _CHUNKHEADER_CHUNKTYPE._serialized_start=1653
  _CHUNKHEADER_CHUNKTYPE._serialized_end=1689
  _DATASETPROFILEHEADER._serialized_start=1692
  _DATASETPROFILEHEADER._serialized_end=2080
  _DATASETPROFILEHEADER_COLUMNOFFSETSENTRY._serialized_start=1954
  _DATASETPROFILEHEADER_COLUMNOFFSETSENTRY._serialized_end=2021
  _DATASETPROFILEHEADER_INDEXEDMETRICPATHSENTRY._serialized_start=2023
  _DATASETPROFILEHEADER_INDEXEDMETRICPATHSENTRY._serialized_end=2080
  _SEGMENTTAG._serialized_start=2082
  _SEGMENTTAG._serialized_end=2122
  _SEGMENT._serialized_start=2124
  _SEGMENT._serialized_end=2182
  _SEGMENTATIONPARTITION._serialized_start=2184
  _SEGMENTATIONPARTITION._serialized_end=2233
  _DATASETSEGMENTHEADER._serialized_start=2236
  _DATASETSEGMENTHEADER._serialized_end=2409
  _DATASETSEGMENTHEADER_OFFSETSENTRY._serialized_start=2363
  _DATASETSEGMENTHEADER_OFFSETSENTRY._serialized_end=2409
# @@protoc_insertion_point(module_scope)
