"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import typing
import typing_extensions
import v0_messages_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UniqueCountSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ESTIMATE_FIELD_NUMBER: builtins.int
    UPPER_FIELD_NUMBER: builtins.int
    LOWER_FIELD_NUMBER: builtins.int
    estimate: builtins.float
    upper: builtins.float
    lower: builtins.float
    def __init__(self,
        *,
        estimate: builtins.float = ...,
        upper: builtins.float = ...,
        lower: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["estimate",b"estimate","lower",b"lower","upper",b"upper"]) -> None: ...
global___UniqueCountSummary = UniqueCountSummary

class FrequentStringsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class FrequentItem(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        VALUE_FIELD_NUMBER: builtins.int
        ESTIMATE_FIELD_NUMBER: builtins.int
        value: typing.Text
        estimate: builtins.float
        def __init__(self,
            *,
            value: typing.Text = ...,
            estimate: builtins.float = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["estimate",b"estimate","value",b"value"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrequentStringsSummary.FrequentItem]: ...
    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___FrequentStringsSummary.FrequentItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items"]) -> None: ...
global___FrequentStringsSummary = FrequentStringsSummary

class FrequentNumbersSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class FrequentDoubleItem(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        ESTIMATE_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        RANK_FIELD_NUMBER: builtins.int
        estimate: builtins.int
        value: builtins.float
        rank: builtins.int
        def __init__(self,
            *,
            estimate: builtins.int = ...,
            value: builtins.float = ...,
            rank: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["estimate",b"estimate","rank",b"rank","value",b"value"]) -> None: ...

    class FrequentLongItem(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        ESTIMATE_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        RANK_FIELD_NUMBER: builtins.int
        estimate: builtins.int
        value: builtins.int
        rank: builtins.int
        def __init__(self,
            *,
            estimate: builtins.int = ...,
            value: builtins.int = ...,
            rank: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["estimate",b"estimate","rank",b"rank","value",b"value"]) -> None: ...

    DOUBLES_FIELD_NUMBER: builtins.int
    LONGS_FIELD_NUMBER: builtins.int
    @property
    def doubles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrequentNumbersSummary.FrequentDoubleItem]: ...
    @property
    def longs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrequentNumbersSummary.FrequentLongItem]: ...
    def __init__(self,
        *,
        doubles: typing.Optional[typing.Iterable[global___FrequentNumbersSummary.FrequentDoubleItem]] = ...,
        longs: typing.Optional[typing.Iterable[global___FrequentNumbersSummary.FrequentLongItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["doubles",b"doubles","longs",b"longs"]) -> None: ...
global___FrequentNumbersSummary = FrequentNumbersSummary

class FrequentItemsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class FrequentItem(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        ESTIMATE_FIELD_NUMBER: builtins.int
        JSON_VALUE_FIELD_NUMBER: builtins.int
        estimate: builtins.int
        json_value: typing.Text
        def __init__(self,
            *,
            estimate: builtins.int = ...,
            json_value: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["estimate",b"estimate","json_value",b"json_value"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrequentItemsSummary.FrequentItem]: ...
    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___FrequentItemsSummary.FrequentItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items"]) -> None: ...
global___FrequentItemsSummary = FrequentItemsSummary

class CharPosSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class CharPosMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___NumberSummary: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___NumberSummary] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    CHARACTER_LIST_FIELD_NUMBER: builtins.int
    CHAR_POS_MAP_FIELD_NUMBER: builtins.int
    character_list: typing.Text
    @property
    def char_pos_map(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___NumberSummary]: ...
    def __init__(self,
        *,
        character_list: typing.Text = ...,
        char_pos_map: typing.Optional[typing.Mapping[typing.Text, global___NumberSummary]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["char_pos_map",b"char_pos_map","character_list",b"character_list"]) -> None: ...
global___CharPosSummary = CharPosSummary

class StringsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UNIQUE_COUNT_FIELD_NUMBER: builtins.int
    FREQUENT_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    TOKEN_LENGTH_FIELD_NUMBER: builtins.int
    CHAR_POS_TRACKER_FIELD_NUMBER: builtins.int
    @property
    def unique_count(self) -> global___UniqueCountSummary: ...
    @property
    def frequent(self) -> global___FrequentStringsSummary: ...
    @property
    def length(self) -> global___NumberSummary: ...
    @property
    def token_length(self) -> global___NumberSummary: ...
    @property
    def char_pos_tracker(self) -> global___CharPosSummary: ...
    def __init__(self,
        *,
        unique_count: typing.Optional[global___UniqueCountSummary] = ...,
        frequent: typing.Optional[global___FrequentStringsSummary] = ...,
        length: typing.Optional[global___NumberSummary] = ...,
        token_length: typing.Optional[global___NumberSummary] = ...,
        char_pos_tracker: typing.Optional[global___CharPosSummary] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["char_pos_tracker",b"char_pos_tracker","frequent",b"frequent","length",b"length","token_length",b"token_length","unique_count",b"unique_count"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["char_pos_tracker",b"char_pos_tracker","frequent",b"frequent","length",b"length","token_length",b"token_length","unique_count",b"unique_count"]) -> None: ...
global___StringsSummary = StringsSummary

class SchemaSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class TypeCountsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.int
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    INFERRED_TYPE_FIELD_NUMBER: builtins.int
    TYPE_COUNTS_FIELD_NUMBER: builtins.int
    @property
    def inferred_type(self) -> v0_messages_pb2.InferredType: ...
    @property
    def type_counts(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.int]: ...
    def __init__(self,
        *,
        inferred_type: typing.Optional[v0_messages_pb2.InferredType] = ...,
        type_counts: typing.Optional[typing.Mapping[typing.Text, builtins.int]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inferred_type",b"inferred_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inferred_type",b"inferred_type","type_counts",b"type_counts"]) -> None: ...
global___SchemaSummary = SchemaSummary

class HistogramSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    COUNTS_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    BINS_FIELD_NUMBER: builtins.int
    N_FIELD_NUMBER: builtins.int
    start: builtins.float
    end: builtins.float
    width: builtins.float
    @property
    def counts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    max: builtins.float
    min: builtins.float
    @property
    def bins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    n: builtins.int
    def __init__(self,
        *,
        start: builtins.float = ...,
        end: builtins.float = ...,
        width: builtins.float = ...,
        counts: typing.Optional[typing.Iterable[builtins.int]] = ...,
        max: builtins.float = ...,
        min: builtins.float = ...,
        bins: typing.Optional[typing.Iterable[builtins.float]] = ...,
        n: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bins",b"bins","counts",b"counts","end",b"end","max",b"max","min",b"min","n",b"n","start",b"start","width",b"width"]) -> None: ...
global___HistogramSummary = HistogramSummary

class QuantileSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QUANTILES_FIELD_NUMBER: builtins.int
    QUANTILE_VALUES_FIELD_NUMBER: builtins.int
    @property
    def quantiles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    @property
    def quantile_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        quantiles: typing.Optional[typing.Iterable[builtins.float]] = ...,
        quantile_values: typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["quantile_values",b"quantile_values","quantiles",b"quantiles"]) -> None: ...
global___QuantileSummary = QuantileSummary

class NumberSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COUNT_FIELD_NUMBER: builtins.int
    MIN_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    MEAN_FIELD_NUMBER: builtins.int
    STDDEV_FIELD_NUMBER: builtins.int
    HISTOGRAM_FIELD_NUMBER: builtins.int
    UNIQUE_COUNT_FIELD_NUMBER: builtins.int
    QUANTILES_FIELD_NUMBER: builtins.int
    FREQUENT_NUMBERS_FIELD_NUMBER: builtins.int
    IS_DISCRETE_FIELD_NUMBER: builtins.int
    count: builtins.int
    min: builtins.float
    max: builtins.float
    mean: builtins.float
    stddev: builtins.float
    @property
    def histogram(self) -> global___HistogramSummary: ...
    @property
    def unique_count(self) -> global___UniqueCountSummary: ...
    @property
    def quantiles(self) -> global___QuantileSummary: ...
    @property
    def frequent_numbers(self) -> global___FrequentNumbersSummary: ...
    is_discrete: builtins.bool
    def __init__(self,
        *,
        count: builtins.int = ...,
        min: builtins.float = ...,
        max: builtins.float = ...,
        mean: builtins.float = ...,
        stddev: builtins.float = ...,
        histogram: typing.Optional[global___HistogramSummary] = ...,
        unique_count: typing.Optional[global___UniqueCountSummary] = ...,
        quantiles: typing.Optional[global___QuantileSummary] = ...,
        frequent_numbers: typing.Optional[global___FrequentNumbersSummary] = ...,
        is_discrete: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["frequent_numbers",b"frequent_numbers","histogram",b"histogram","quantiles",b"quantiles","unique_count",b"unique_count"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count",b"count","frequent_numbers",b"frequent_numbers","histogram",b"histogram","is_discrete",b"is_discrete","max",b"max","mean",b"mean","min",b"min","quantiles",b"quantiles","stddev",b"stddev","unique_count",b"unique_count"]) -> None: ...
global___NumberSummary = NumberSummary

class ColumnSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COUNTERS_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    NUMBER_SUMMARY_FIELD_NUMBER: builtins.int
    STRING_SUMMARY_FIELD_NUMBER: builtins.int
    FREQUENT_ITEMS_FIELD_NUMBER: builtins.int
    UNIQUE_COUNT_FIELD_NUMBER: builtins.int
    @property
    def counters(self) -> v0_messages_pb2.CountersV0: ...
    @property
    def schema(self) -> global___SchemaSummary: ...
    @property
    def number_summary(self) -> global___NumberSummary: ...
    @property
    def string_summary(self) -> global___StringsSummary: ...
    @property
    def frequent_items(self) -> global___FrequentItemsSummary: ...
    @property
    def unique_count(self) -> global___UniqueCountSummary: ...
    def __init__(self,
        *,
        counters: typing.Optional[v0_messages_pb2.CountersV0] = ...,
        schema: typing.Optional[global___SchemaSummary] = ...,
        number_summary: typing.Optional[global___NumberSummary] = ...,
        string_summary: typing.Optional[global___StringsSummary] = ...,
        frequent_items: typing.Optional[global___FrequentItemsSummary] = ...,
        unique_count: typing.Optional[global___UniqueCountSummary] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["counters",b"counters","frequent_items",b"frequent_items","number_summary",b"number_summary","schema",b"schema","string_summary",b"string_summary","unique_count",b"unique_count"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["counters",b"counters","frequent_items",b"frequent_items","number_summary",b"number_summary","schema",b"schema","string_summary",b"string_summary","unique_count",b"unique_count"]) -> None: ...
global___ColumnSummary = ColumnSummary

class DatasetSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class ColumnsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___ColumnSummary: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___ColumnSummary] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    PROPERTIES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    @property
    def properties(self) -> v0_messages_pb2.DatasetPropertiesV0: ...
    @property
    def columns(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___ColumnSummary]: ...
    @property
    def model(self) -> global___ModelSummary: ...
    def __init__(self,
        *,
        properties: typing.Optional[v0_messages_pb2.DatasetPropertiesV0] = ...,
        columns: typing.Optional[typing.Mapping[typing.Text, global___ColumnSummary]] = ...,
        model: typing.Optional[global___ModelSummary] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model",b"model","properties",b"properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["columns",b"columns","model",b"model","properties",b"properties"]) -> None: ...
global___DatasetSummary = DatasetSummary

class ModelSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    METRICS_FIELD_NUMBER: builtins.int
    @property
    def metrics(self) -> global___MetricsSummary: ...
    def __init__(self,
        *,
        metrics: typing.Optional[global___MetricsSummary] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metrics",b"metrics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metrics",b"metrics"]) -> None: ...
global___ModelSummary = ModelSummary

class MetricsSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODEL_TYPE_FIELD_NUMBER: builtins.int
    ROC_FPR_TPR_FIELD_NUMBER: builtins.int
    RECALL_PREC_FIELD_NUMBER: builtins.int
    CONFUSION_MATRIX_FIELD_NUMBER: builtins.int
    model_type: v0_messages_pb2.ModelType.ValueType
    @property
    def roc_fpr_tpr(self) -> global___ROCCurve: ...
    @property
    def recall_prec(self) -> global___RecallCurve: ...
    @property
    def confusion_matrix(self) -> global___ConfusionMatrix: ...
    def __init__(self,
        *,
        model_type: v0_messages_pb2.ModelType.ValueType = ...,
        roc_fpr_tpr: typing.Optional[global___ROCCurve] = ...,
        recall_prec: typing.Optional[global___RecallCurve] = ...,
        confusion_matrix: typing.Optional[global___ConfusionMatrix] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["confusion_matrix",b"confusion_matrix","recall_prec",b"recall_prec","roc_fpr_tpr",b"roc_fpr_tpr"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["confusion_matrix",b"confusion_matrix","model_type",b"model_type","recall_prec",b"recall_prec","roc_fpr_tpr",b"roc_fpr_tpr"]) -> None: ...
global___MetricsSummary = MetricsSummary

class ConfusionMatrix(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LABELS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_FIELD_NUMBER: builtins.int
    PREDICTIONS_FIELD_FIELD_NUMBER: builtins.int
    SCORE_FIELD_FIELD_NUMBER: builtins.int
    COUNTS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    target_field: typing.Text
    predictions_field: typing.Text
    score_field: typing.Text
    @property
    def counts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.ListValue]:
        """e.g. [[33, 6], [11, 27]]"""
        pass
    def __init__(self,
        *,
        labels: typing.Optional[typing.Iterable[typing.Text]] = ...,
        target_field: typing.Text = ...,
        predictions_field: typing.Text = ...,
        score_field: typing.Text = ...,
        counts: typing.Optional[typing.Iterable[google.protobuf.struct_pb2.ListValue]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["counts",b"counts","labels",b"labels","predictions_field",b"predictions_field","score_field",b"score_field","target_field",b"target_field"]) -> None: ...
global___ConfusionMatrix = ConfusionMatrix

class ROCCurve(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.ListValue]:
        """e.g.   "values": [ [1, 0.42857],  [1, 0.42857], ... ]"""
        pass
    def __init__(self,
        *,
        values: typing.Optional[typing.Iterable[google.protobuf.struct_pb2.ListValue]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["values",b"values"]) -> None: ...
global___ROCCurve = ROCCurve

class RecallCurve(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.ListValue]:
        """e.g.   "values": [ [1, 1],  [1, 1], ... ]"""
        pass
    def __init__(self,
        *,
        values: typing.Optional[typing.Iterable[google.protobuf.struct_pb2.ListValue]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["values",b"values"]) -> None: ...
global___RecallCurve = RecallCurve

class DatasetSummaries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class ProfilesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___DatasetSummary: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___DatasetSummary] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    PROFILES_FIELD_NUMBER: builtins.int
    @property
    def profiles(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___DatasetSummary]: ...
    def __init__(self,
        *,
        profiles: typing.Optional[typing.Mapping[typing.Text, global___DatasetSummary]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["profiles",b"profiles"]) -> None: ...
global___DatasetSummaries = DatasetSummaries
